# TSCCM

**TSCCM** *(Tenable.SC CLI Manager)* by LimberDuck is a CLI tool which enables you to perform certain actions on Tenable.SC by (C) Tenable, Inc. via [Tenable.SC API](https://docs.tenable.com/tenablesc/api).

[![pepy - Downloads](https://img.shields.io/pepy/dt/tsccm?logo=PyPI)](https://pepy.tech/projects/tsccm) [![PyPI Downloads](https://static.pepy.tech/badge/tsccm/month)](https://pepy.tech/projects/tsccm)
[![Latest Release version](https://img.shields.io/github/v/release/LimberDuck/tsccm?label=Latest%20release)](https://github.com/LimberDuck/tsccm/releases) 
[![GitHub Release Date](https://img.shields.io/github/release-date/limberduck/tsccm?label=released&logo=GitHub)](https://github.com/LimberDuck/tsccm/releases)
[![License](https://img.shields.io/github/license/LimberDuck/tsccm.svg)](https://github.com/LimberDuck/tsccm/blob/main/LICENSE) [![Repo size](https://img.shields.io/github/repo-size/LimberDuck/tsccm.svg)](https://github.com/LimberDuck/tsccm) [![Code size](https://img.shields.io/github/languages/code-size/LimberDuck/tsccm.svg)](https://github.com/LimberDuck/tsccm) [![Supported platform](https://img.shields.io/badge/platform-windows%20%7C%20macos%20%7C%20linux-lightgrey.svg)](https://github.com/LimberDuck/tsccm)
<!-- [![PyPI - Downloads](https://img.shields.io/pypi/dm/tsccm?logo=PyPI)](https://pypi.org/project/tsccm/) -->


Main features
=============

Initial version of **TSCCM** lets you get Tenable.SC's:
* audit file list
* credential list  
* group list
* policy list
* role list
* active scan list
* scan result list
* server info
  * status
  * licensed IPs
  * version
* users list


How to
======

1. Install
    
    `pip install tsccm`

2. Run

    `tsccm`

Meta
====

Change log
----------

See [CHANGELOG].


Licence
-------

MIT: [LICENSE].


Authors
-------

[Damian Krawczyk] created **TSCCM** *(Tenable.SC CLI Manager)* by LimberDuck.

[Damian Krawczyk]: https://damiankrawczyk.com

[CHANGELOG]: https://github.com/LimberDuck/tsccm/blob/main/CHANGELOG.md
[LICENSE]: https://github.com/LimberDuck/tsccm/blob/main/LICENSE


